/* ovirt-broker.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from ovirt-broker.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <govirt/govirt.h>
#include <gtk/gtk.h>
#include <libxml/uri.h>
#include <rest/rest-proxy.h>
#include <rest/oauth-proxy-call.h>
#include <rest/oauth-proxy.h>
#include <rest/oauth2-proxy-call.h>
#include <rest/oauth2-proxy.h>
#include <rest/rest-enum-types.h>
#include <rest/rest-param.h>
#include <rest/rest-params.h>
#include <rest/rest-proxy-auth.h>
#include <rest/rest-proxy-call.h>
#include <rest/rest-xml-node.h>
#include <rest/rest-xml-parser.h>
#include <libgd/gd.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_BROKER (boxes_broker_get_type ())
#define BOXES_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_BROKER, BoxesBroker))
#define BOXES_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_BROKER, BoxesBrokerClass))
#define BOXES_IS_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_BROKER))
#define BOXES_IS_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_BROKER))
#define BOXES_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_BROKER, BoxesBrokerClass))

typedef struct _BoxesBroker BoxesBroker;
typedef struct _BoxesBrokerClass BoxesBrokerClass;
typedef struct _BoxesBrokerPrivate BoxesBrokerPrivate;

#define BOXES_TYPE_OVIRT_BROKER (boxes_ovirt_broker_get_type ())
#define BOXES_OVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OVIRT_BROKER, BoxesOvirtBroker))
#define BOXES_OVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OVIRT_BROKER, BoxesOvirtBrokerClass))
#define BOXES_IS_OVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OVIRT_BROKER))
#define BOXES_IS_OVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OVIRT_BROKER))
#define BOXES_OVIRT_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OVIRT_BROKER, BoxesOvirtBrokerClass))

typedef struct _BoxesOvirtBroker BoxesOvirtBroker;
typedef struct _BoxesOvirtBrokerClass BoxesOvirtBrokerClass;
typedef struct _BoxesOvirtBrokerPrivate BoxesOvirtBrokerPrivate;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_OVIRT_MACHINE (boxes_ovirt_machine_get_type ())
#define BOXES_OVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OVIRT_MACHINE, BoxesOvirtMachine))
#define BOXES_OVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OVIRT_MACHINE, BoxesOvirtMachineClass))
#define BOXES_IS_OVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OVIRT_MACHINE))
#define BOXES_IS_OVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OVIRT_MACHINE))
#define BOXES_OVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OVIRT_MACHINE, BoxesOvirtMachineClass))

typedef struct _BoxesOvirtMachine BoxesOvirtMachine;
typedef struct _BoxesOvirtMachineClass BoxesOvirtMachineClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block76Data Block76Data;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _g_byte_array_unref0(var) ((var == NULL) ? NULL : (var = (g_byte_array_unref (var), NULL)))
#define _xmlFreeURI0(var) ((var == NULL) ? NULL : (var = (xmlFreeURI (var), NULL)))
typedef struct _BoxesOvirtBrokerAddSourceData BoxesOvirtBrokerAddSourceData;

struct _BoxesBroker {
	GObject parent_instance;
	BoxesBrokerPrivate * priv;
};

struct _BoxesBrokerClass {
	GObjectClass parent_class;
	void (*add_source) (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*add_source_finish) (BoxesBroker* self, GAsyncResult* _res_);
};

struct _BoxesOvirtBroker {
	BoxesBroker parent_instance;
	BoxesOvirtBrokerPrivate * priv;
};

struct _BoxesOvirtBrokerClass {
	BoxesBrokerClass parent_class;
};

struct _BoxesOvirtBrokerPrivate {
	GHashTable* proxies;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollectionItem* current_item;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _Block76Data {
	int _ref_count_;
	BoxesOvirtBroker* self;
	RestProxy* proxy;
	RestProxyAuth* auth;
};

typedef void (*BoxesAuthNotificationAuthFunc) (const gchar* username, const gchar* password, void* user_data);
typedef void (*BoxesNotificationCancelFunc) (void* user_data);
struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _BoxesOvirtBrokerAddSourceData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesOvirtBroker* self;
	BoxesCollectionSource* source;
	GHashTable* _tmp0_;
	BoxesCollectionSource* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gconstpointer _tmp5_;
	gboolean _tmp6_;
	xmlURI* uri;
	BoxesCollectionSource* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	xmlURI* _tmp11_;
	xmlURI* _tmp12_;
	xmlURI* _tmp13_;
	const gchar* _tmp14_;
	xmlURI* _tmp15_;
	gchar* _tmp16_;
	xmlURI* _tmp17_;
	const gchar* _tmp18_;
	xmlURI* _tmp19_;
	gchar* _tmp20_;
	xmlURI* _tmp21_;
	xmlURI* _tmp22_;
	const gchar* _tmp23_;
	gchar* _tmp24_;
	OvirtProxy* proxy;
	xmlURI* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	OvirtProxy* _tmp28_;
	OvirtProxy* _tmp29_;
	OvirtProxy* _tmp30_;
	OvirtProxy* _tmp31_;
	GByteArray* _tmp32_;
	GByteArray* _tmp33_;
	OvirtProxy* _tmp34_;
	GError* _error_;
	GError* _tmp35_;
	const gchar* _tmp36_;
	BoxesAppWindow* _tmp37_;
	BoxesNotificationbar* _tmp38_;
	const gchar* _tmp39_;
	GdNotification* _tmp40_;
	GdNotification* _tmp41_;
	GHashTable* _tmp42_;
	BoxesCollectionSource* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	OvirtProxy* _tmp46_;
	OvirtProxy* _tmp47_;
	OvirtProxy* _tmp48_;
	GList* _tmp49_;
	GList* vm_collection;
	GList* vm_it;
	OvirtVm* _tmp50_;
	OvirtVm* vm;
	BoxesCollectionSource* _tmp51_;
	OvirtProxy* _tmp52_;
	OvirtVm* _tmp53_;
	BoxesCollectionSource* _tmp54_;
	GError * _inner_error_;
};


static gpointer boxes_ovirt_broker_parent_class = NULL;
static BoxesOvirtBroker* boxes_ovirt_broker_broker;
static BoxesOvirtBroker* boxes_ovirt_broker_broker = NULL;
extern BoxesApp* boxes_app_app;
extern BoxesAppWindow* boxes_app_window;

GType boxes_broker_get_type (void) G_GNUC_CONST;
GType boxes_ovirt_broker_get_type (void) G_GNUC_CONST;
#define BOXES_OVIRT_BROKER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_OVIRT_BROKER, BoxesOvirtBrokerPrivate))
enum  {
	BOXES_OVIRT_BROKER_DUMMY_PROPERTY
};
BoxesOvirtBroker* boxes_ovirt_broker_get_default (void);
static BoxesOvirtBroker* boxes_ovirt_broker_new (void);
static BoxesOvirtBroker* boxes_ovirt_broker_construct (GType object_type);
BoxesBroker* boxes_broker_construct (GType object_type);
static void _g_free0_ (gpointer var);
static void _g_object_unref0_ (gpointer var);
static void boxes_ovirt_broker_add_vm (BoxesOvirtBroker* self, BoxesCollectionSource* source, OvirtProxy* proxy, OvirtVm* vm);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_ovirt_machine_get_type (void) G_GNUC_CONST;
BoxesOvirtMachine* boxes_ovirt_machine_new (BoxesCollectionSource* source, OvirtProxy* proxy, OvirtVm* vm, GError** error);
BoxesOvirtMachine* boxes_ovirt_machine_construct (GType object_type, BoxesCollectionSource* source, OvirtProxy* proxy, OvirtVm* vm, GError** error);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
void boxes_collection_add_item (BoxesCollection* self, BoxesCollectionItem* item);
static void boxes_ovirt_broker_real_add_source_data_free (gpointer _data);
static void boxes_ovirt_broker_real_add_source (BoxesBroker* base, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_ovirt_broker_real_add_source_co (BoxesOvirtBrokerAddSourceData* _data_);
static gboolean __lambda169_ (BoxesOvirtBroker* self, RestProxy* proxy, RestProxyAuth* auth, gboolean retrying);
static Block76Data* block76_data_ref (Block76Data* _data76_);
static void block76_data_unref (void * _userdata_);
static void __lambda170_ (Block76Data* _data76_, const gchar* username, const gchar* password);
static void ___lambda170__boxes_auth_notification_auth_func (const gchar* username, const gchar* password, gpointer self);
static void __lambda171_ (Block76Data* _data76_);
static void ___lambda171__boxes_notification_cancel_func (gpointer self);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GdNotification* boxes_notificationbar_display_for_optional_auth (BoxesNotificationbar* self, const gchar* broker_name, BoxesAuthNotificationAuthFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationCancelFunc cancel_func, void* cancel_func_target, GDestroyNotify cancel_func_target_destroy_notify);
static gboolean ___lambda169__rest_proxy_authenticate (RestProxy* _sender, RestProxyAuth* auth, gboolean retrying, gpointer self);
static void boxes_ovirt_broker_add_source_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
void boxes_broker_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_broker_add_source_finish (BoxesBroker* self, GAsyncResult* _res_);
static void boxes_ovirt_broker_finalize (GObject* obj);


static gpointer _g_object_ref0 (gpointer self) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	return self ? g_object_ref (self) : NULL;
#line 451 "ovirt-broker.c"
}


BoxesOvirtBroker* boxes_ovirt_broker_get_default (void) {
	BoxesOvirtBroker* result = NULL;
	BoxesOvirtBroker* _tmp0_ = NULL;
	BoxesOvirtBroker* _tmp2_ = NULL;
	BoxesOvirtBroker* _tmp3_ = NULL;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp0_ = boxes_ovirt_broker_broker;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	if (_tmp0_ == NULL) {
#line 464 "ovirt-broker.c"
		BoxesOvirtBroker* _tmp1_ = NULL;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_tmp1_ = boxes_ovirt_broker_new ();
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_g_object_unref0 (boxes_ovirt_broker_broker);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		boxes_ovirt_broker_broker = _tmp1_;
#line 472 "ovirt-broker.c"
	}
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp2_ = boxes_ovirt_broker_broker;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	result = _tmp3_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	return result;
#line 482 "ovirt-broker.c"
}


static void _g_free0_ (gpointer var) {
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	var = (g_free (var), NULL);
#line 489 "ovirt-broker.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 496 "ovirt-broker.c"
}


static BoxesOvirtBroker* boxes_ovirt_broker_construct (GType object_type) {
	BoxesOvirtBroker * self = NULL;
	GHashFunc _tmp0_ = NULL;
	GEqualFunc _tmp1_ = NULL;
	GHashTable* _tmp2_ = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	self = (BoxesOvirtBroker*) boxes_broker_construct (object_type);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp0_ = g_str_hash;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp1_ = g_str_equal;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, _g_free0_, _g_object_unref0_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_g_hash_table_unref0 (self->priv->proxies);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	self->priv->proxies = _tmp2_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	return self;
#line 519 "ovirt-broker.c"
}


static BoxesOvirtBroker* boxes_ovirt_broker_new (void) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	return boxes_ovirt_broker_construct (BOXES_TYPE_OVIRT_BROKER);
#line 526 "ovirt-broker.c"
}


static void boxes_ovirt_broker_add_vm (BoxesOvirtBroker* self, BoxesCollectionSource* source, OvirtProxy* proxy, OvirtVm* vm) {
	GError * _inner_error_ = NULL;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_return_if_fail (self != NULL);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_return_if_fail (source != NULL);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_return_if_fail (proxy != NULL);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_return_if_fail (vm != NULL);
#line 540 "ovirt-broker.c"
	{
		BoxesOvirtMachine* machine = NULL;
		BoxesCollectionSource* _tmp0_ = NULL;
		OvirtProxy* _tmp1_ = NULL;
		OvirtVm* _tmp2_ = NULL;
		BoxesOvirtMachine* _tmp3_ = NULL;
		BoxesApp* _tmp4_ = NULL;
		BoxesCollection* _tmp5_ = NULL;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_tmp0_ = source;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_tmp1_ = proxy;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_tmp2_ = vm;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_tmp3_ = boxes_ovirt_machine_new (_tmp0_, _tmp1_, _tmp2_, &_inner_error_);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		machine = _tmp3_;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 561 "ovirt-broker.c"
			goto __catch122_g_error;
		}
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_tmp4_ = boxes_app_app;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_tmp5_ = _tmp4_->collection;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		boxes_collection_add_item (_tmp5_, (BoxesCollectionItem*) machine);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_g_object_unref0 (machine);
#line 572 "ovirt-broker.c"
	}
	goto __finally122;
	__catch122_g_error:
	{
		GError* _error_ = NULL;
		BoxesCollectionSource* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		GError* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_error_ = _inner_error_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_inner_error_ = NULL;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_tmp6_ = source;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_tmp7_ = boxes_collection_source_get_name (_tmp6_);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_tmp8_ = _tmp7_;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_tmp9_ = _tmp8_;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_tmp10_ = _error_;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_tmp11_ = _tmp10_->message;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		g_warning ("ovirt-broker.vala:24: Failed to create source '%s': %s", _tmp9_, _tmp11_);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_g_free0 (_tmp9_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_g_error_free0 (_error_);
#line 606 "ovirt-broker.c"
	}
	__finally122:
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		g_clear_error (&_inner_error_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		return;
#line 617 "ovirt-broker.c"
	}
}


static void boxes_ovirt_broker_real_add_source_data_free (gpointer _data) {
	BoxesOvirtBrokerAddSourceData* _data_;
	_data_ = _data;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_g_object_unref0 (_data_->source);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_g_object_unref0 (_data_->self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_slice_free (BoxesOvirtBrokerAddSourceData, _data_);
#line 631 "ovirt-broker.c"
}


static void boxes_ovirt_broker_real_add_source (BoxesBroker* base, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesOvirtBroker * self;
	BoxesOvirtBrokerAddSourceData* _data_;
	BoxesOvirtBroker* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	self = (BoxesOvirtBroker*) base;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_ = g_slice_new0 (BoxesOvirtBrokerAddSourceData);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_ovirt_broker_real_add_source);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_ovirt_broker_real_add_source_data_free);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->self = _tmp0_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp1_ = source;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_g_object_unref0 (_data_->source);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->source = _tmp2_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	boxes_ovirt_broker_real_add_source_co (_data_);
#line 663 "ovirt-broker.c"
}


static void boxes_ovirt_broker_real_add_source_finish (BoxesBroker* base, GAsyncResult* _res_) {
	BoxesOvirtBrokerAddSourceData* _data_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 671 "ovirt-broker.c"
}


static Block76Data* block76_data_ref (Block76Data* _data76_) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_atomic_int_inc (&_data76_->_ref_count_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	return _data76_;
#line 680 "ovirt-broker.c"
}


static void block76_data_unref (void * _userdata_) {
	Block76Data* _data76_;
	_data76_ = (Block76Data*) _userdata_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	if (g_atomic_int_dec_and_test (&_data76_->_ref_count_)) {
#line 689 "ovirt-broker.c"
		BoxesOvirtBroker* self;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		self = _data76_->self;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_g_object_unref0 (_data76_->proxy);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_g_object_unref0 (_data76_->auth);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_g_object_unref0 (self);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		g_slice_free (Block76Data, _data76_);
#line 701 "ovirt-broker.c"
	}
}


static void __lambda170_ (Block76Data* _data76_, const gchar* username, const gchar* password) {
	BoxesOvirtBroker* self;
	RestProxy* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	RestProxy* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	RestProxyAuth* _tmp4_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	self = _data76_->self;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_return_if_fail (username != NULL);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_return_if_fail (password != NULL);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp0_ = _data76_->proxy;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp1_ = username;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_object_set (_tmp0_, "username", _tmp1_, NULL);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp2_ = _data76_->proxy;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp3_ = password;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_object_set (_tmp2_, "password", _tmp3_, NULL);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp4_ = _data76_->auth;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	rest_proxy_auth_unpause (_tmp4_);
#line 735 "ovirt-broker.c"
}


static void ___lambda170__boxes_auth_notification_auth_func (const gchar* username, const gchar* password, gpointer self) {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	__lambda170_ (self, username, password);
#line 742 "ovirt-broker.c"
}


static void __lambda171_ (Block76Data* _data76_) {
	BoxesOvirtBroker* self;
	RestProxyAuth* _tmp0_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	self = _data76_->self;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp0_ = _data76_->auth;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	rest_proxy_auth_unpause (_tmp0_);
#line 755 "ovirt-broker.c"
}


static void ___lambda171__boxes_notification_cancel_func (gpointer self) {
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	__lambda171_ (self);
#line 762 "ovirt-broker.c"
}


static gboolean __lambda169_ (BoxesOvirtBroker* self, RestProxy* proxy, RestProxyAuth* auth, gboolean retrying) {
	gboolean result = FALSE;
	Block76Data* _data76_;
	RestProxy* _tmp0_ = NULL;
	RestProxy* _tmp1_ = NULL;
	RestProxyAuth* _tmp2_ = NULL;
	RestProxyAuth* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	BoxesAuthNotificationAuthFunc auth_cb = NULL;
	void* auth_cb_target = NULL;
	GDestroyNotify auth_cb_target_destroy_notify = NULL;
	BoxesNotificationCancelFunc cancel_cb = NULL;
	void* cancel_cb_target = NULL;
	GDestroyNotify cancel_cb_target_destroy_notify = NULL;
	BoxesAppWindow* _tmp5_ = NULL;
	BoxesNotificationbar* _tmp6_ = NULL;
	BoxesAuthNotificationAuthFunc _tmp7_ = NULL;
	void* _tmp7__target = NULL;
	GDestroyNotify _tmp7__target_destroy_notify = NULL;
	BoxesNotificationCancelFunc _tmp8_ = NULL;
	void* _tmp8__target = NULL;
	GDestroyNotify _tmp8__target_destroy_notify = NULL;
	GdNotification* _tmp9_ = NULL;
	GdNotification* _tmp10_ = NULL;
	RestProxyAuth* _tmp11_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_return_val_if_fail (proxy != NULL, FALSE);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_return_val_if_fail (auth != NULL, FALSE);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data76_ = g_slice_new0 (Block76Data);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data76_->_ref_count_ = 1;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data76_->self = g_object_ref (self);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp0_ = proxy;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_g_object_unref0 (_data76_->proxy);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data76_->proxy = _tmp1_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp2_ = auth;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_g_object_unref0 (_data76_->auth);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data76_->auth = _tmp3_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp4_ = retrying;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	if (_tmp4_) {
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		result = FALSE;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		block76_data_unref (_data76_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data76_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		return result;
#line 829 "ovirt-broker.c"
	}
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	auth_cb = ___lambda170__boxes_auth_notification_auth_func;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	auth_cb_target = block76_data_ref (_data76_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	auth_cb_target_destroy_notify = block76_data_unref;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	cancel_cb = ___lambda171__boxes_notification_cancel_func;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	cancel_cb_target = block76_data_ref (_data76_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	cancel_cb_target_destroy_notify = block76_data_unref;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp5_ = boxes_app_window;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp6_ = _tmp5_->notificationbar;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp7_ = auth_cb;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp7__target = auth_cb_target;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp7__target_destroy_notify = auth_cb_target_destroy_notify;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	auth_cb_target_destroy_notify = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp8_ = cancel_cb;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp8__target = cancel_cb_target;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp8__target_destroy_notify = cancel_cb_target_destroy_notify;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	cancel_cb_target_destroy_notify = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp9_ = boxes_notificationbar_display_for_optional_auth (_tmp6_, "oVirt broker", _tmp7_, _tmp7__target, _tmp7__target_destroy_notify, _tmp8_, _tmp8__target, _tmp8__target_destroy_notify);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp10_ = _tmp9_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_g_object_unref0 (_tmp10_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_tmp11_ = _data76_->auth;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	rest_proxy_auth_pause (_tmp11_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	result = FALSE;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	(cancel_cb_target_destroy_notify == NULL) ? NULL : (cancel_cb_target_destroy_notify (cancel_cb_target), NULL);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	cancel_cb = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	cancel_cb_target = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	cancel_cb_target_destroy_notify = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	(auth_cb_target_destroy_notify == NULL) ? NULL : (auth_cb_target_destroy_notify (auth_cb_target), NULL);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	auth_cb = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	auth_cb_target = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	auth_cb_target_destroy_notify = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	block76_data_unref (_data76_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data76_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	return result;
#line 897 "ovirt-broker.c"
}


static gboolean ___lambda169__rest_proxy_authenticate (RestProxy* _sender, RestProxyAuth* auth, gboolean retrying, gpointer self) {
	gboolean result;
	result = __lambda169_ ((BoxesOvirtBroker*) self, _sender, auth, retrying);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	return result;
#line 906 "ovirt-broker.c"
}


static void boxes_ovirt_broker_add_source_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesOvirtBrokerAddSourceData* _data_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_ = _user_data_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_source_object_ = source_object;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_res_ = _res_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	boxes_ovirt_broker_real_add_source_co (_data_);
#line 920 "ovirt-broker.c"
}


static gboolean boxes_ovirt_broker_real_add_source_co (BoxesOvirtBrokerAddSourceData* _data_) {
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	switch (_data_->_state_) {
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		case 0:
#line 929 "ovirt-broker.c"
		goto _state_0;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		case 1:
#line 933 "ovirt-broker.c"
		goto _state_1;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		case 2:
#line 937 "ovirt-broker.c"
		goto _state_2;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		case 3:
#line 941 "ovirt-broker.c"
		goto _state_3;
		default:
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		g_assert_not_reached ();
#line 946 "ovirt-broker.c"
	}
	_state_0:
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp0_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp0_ = _data_->self->priv->proxies;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp1_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp1_ = _data_->source;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp2_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp2_ = boxes_collection_source_get_name (_data_->_tmp1_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp3_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp4_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp5_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp5_ = g_hash_table_lookup (_data_->_tmp0_, _data_->_tmp4_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp6_ = FALSE;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp6_ = ((OvirtProxy*) _data_->_tmp5_) != NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_g_free0 (_data_->_tmp4_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	if (_data_->_tmp6_) {
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		if (_data_->_state_ == 0) {
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 985 "ovirt-broker.c"
		} else {
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 989 "ovirt-broker.c"
		}
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		g_object_unref (_data_->_async_result);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		return FALSE;
#line 995 "ovirt-broker.c"
	}
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp7_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp7_ = _data_->source;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp8_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp8_ = boxes_collection_source_get_uri (_data_->_tmp7_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp9_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp10_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp11_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp11_ = xmlParseURI (_data_->_tmp10_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp12_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp12_ = _data_->_tmp11_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_g_free0 (_data_->_tmp10_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->uri = _data_->_tmp12_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp13_ = NULL;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp13_ = _data_->uri;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp14_ = NULL;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp14_ = _data_->_tmp13_->scheme;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_return_if_fail (g_strcmp0 (_data_->_tmp14_, "ovirt") == 0);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp15_ = NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp15_ = _data_->uri;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp16_ = NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp16_ = g_strdup ("https");
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_g_free0 (_data_->_tmp15_->scheme);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp15_->scheme = _data_->_tmp16_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp17_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp17_ = _data_->uri;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp18_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp18_ = _data_->_tmp17_->path;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	if (_data_->_tmp18_ == NULL) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp19_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp19_ = _data_->uri;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp20_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp20_ = g_strdup ("/api");
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_g_free0 (_data_->_tmp19_->path);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp19_->path = _data_->_tmp20_;
#line 1069 "ovirt-broker.c"
	} else {
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp21_ = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp21_ = _data_->uri;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp22_ = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp22_ = _data_->uri;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp23_ = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp23_ = _data_->_tmp22_->path;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp24_ = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp24_ = g_build_filename (_data_->_tmp23_, "api", NULL);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_g_free0 (_data_->_tmp21_->path);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp21_->path = _data_->_tmp24_;
#line 1091 "ovirt-broker.c"
	}
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp25_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp25_ = _data_->uri;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp26_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp26_ = (gchar*) xmlSaveUri (_data_->_tmp25_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp27_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp27_ = _data_->_tmp26_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp28_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp28_ = ovirt_proxy_new (_data_->_tmp27_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp29_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp29_ = _data_->_tmp28_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_g_free0 (_data_->_tmp27_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->proxy = _data_->_tmp29_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp30_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp30_ = _data_->proxy;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_signal_connect_object ((RestProxy*) _data_->_tmp30_, "authenticate", (GCallback) ___lambda169__rest_proxy_authenticate, _data_->self, 0);
#line 1123 "ovirt-broker.c"
	{
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp31_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp31_ = _data_->proxy;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_state_ = 1;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		ovirt_proxy_fetch_ca_certificate_async (_data_->_tmp31_, NULL, boxes_ovirt_broker_add_source_ready, _data_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		return FALSE;
#line 1135 "ovirt-broker.c"
		_state_1:
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp32_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp32_ = ovirt_proxy_fetch_ca_certificate_finish (_data_->_tmp31_, _data_->_res_, &_data_->_inner_error_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp33_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp33_ = _data_->_tmp32_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_g_byte_array_unref0 (_data_->_tmp33_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1149 "ovirt-broker.c"
			goto __catch123_g_error;
		}
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp34_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp34_ = _data_->proxy;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_state_ = 2;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		ovirt_proxy_fetch_vms_async (_data_->_tmp34_, NULL, boxes_ovirt_broker_add_source_ready, _data_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		return FALSE;
#line 1162 "ovirt-broker.c"
		_state_2:
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		ovirt_proxy_fetch_vms_finish (_data_->_tmp34_, _data_->_res_, &_data_->_inner_error_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1168 "ovirt-broker.c"
			goto __catch123_g_error;
		}
	}
	goto __finally123;
	__catch123_g_error:
	{
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_inner_error_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp35_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp35_ = _data_->_error_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp36_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp36_ = _data_->_tmp35_->message;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		g_debug ("ovirt-broker.vala:68: Failed to connect to broker: %s", _data_->_tmp36_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp37_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp37_ = boxes_app_window;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp38_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp38_ = _data_->_tmp37_->notificationbar;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp39_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp39_ = _ ("Connection to oVirt broker failed");
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp40_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp40_ = boxes_notificationbar_display_error (_data_->_tmp38_, _data_->_tmp39_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp41_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->_tmp41_ = _data_->_tmp40_;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_g_object_unref0 (_data_->_tmp41_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_g_error_free0 (_data_->_error_);
#line 1213 "ovirt-broker.c"
	}
	__finally123:
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_g_object_unref0 (_data_->proxy);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_xmlFreeURI0 (_data_->uri);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		g_clear_error (&_data_->_inner_error_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		return FALSE;
#line 1228 "ovirt-broker.c"
	}
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp42_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp42_ = _data_->self->priv->proxies;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp43_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp43_ = _data_->source;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp44_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp44_ = boxes_collection_source_get_name (_data_->_tmp43_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp45_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp45_ = _data_->_tmp44_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp46_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp46_ = _data_->proxy;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp47_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp47_ = _g_object_ref0 (_data_->_tmp46_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_hash_table_insert (_data_->_tmp42_, _data_->_tmp45_, _data_->_tmp47_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp48_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp48_ = _data_->proxy;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp49_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp49_ = ovirt_proxy_get_vms (_data_->_tmp48_);
#line 1264 "ovirt-broker.c"
	{
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		_data_->vm_collection = _data_->_tmp49_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		for (_data_->vm_it = _data_->vm_collection; _data_->vm_it != NULL; _data_->vm_it = _data_->vm_it->next) {
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
			_data_->_tmp50_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
			_data_->_tmp50_ = _g_object_ref0 ((OvirtVm*) _data_->vm_it->data);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
			_data_->vm = _data_->_tmp50_;
#line 1276 "ovirt-broker.c"
			{
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
				_data_->_tmp51_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
				_data_->_tmp51_ = _data_->source;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
				_data_->_tmp52_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
				_data_->_tmp52_ = _data_->proxy;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
				_data_->_tmp53_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
				_data_->_tmp53_ = _data_->vm;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
				boxes_ovirt_broker_add_vm (_data_->self, _data_->_tmp51_, _data_->_tmp52_, _data_->_tmp53_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
				_g_object_unref0 (_data_->vm);
#line 1294 "ovirt-broker.c"
			}
		}
	}
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp54_ = NULL;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_tmp54_ = _data_->source;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_data_->_state_ = 3;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	BOXES_BROKER_CLASS (boxes_ovirt_broker_parent_class)->add_source (G_TYPE_CHECK_INSTANCE_CAST (_data_->self, BOXES_TYPE_BROKER, BoxesBroker), _data_->_tmp54_, boxes_ovirt_broker_add_source_ready, _data_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	return FALSE;
#line 1308 "ovirt-broker.c"
	_state_3:
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	BOXES_BROKER_CLASS (boxes_ovirt_broker_parent_class)->add_source_finish (G_TYPE_CHECK_INSTANCE_CAST (_data_->self, BOXES_TYPE_BROKER, BoxesBroker), _data_->_res_);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_g_object_unref0 (_data_->proxy);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_xmlFreeURI0 (_data_->uri);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	if (_data_->_state_ == 0) {
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1320 "ovirt-broker.c"
	} else {
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1324 "ovirt-broker.c"
	}
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_object_unref (_data_->_async_result);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	return FALSE;
#line 1330 "ovirt-broker.c"
}


static void boxes_ovirt_broker_class_init (BoxesOvirtBrokerClass * klass) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	boxes_ovirt_broker_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	g_type_class_add_private (klass, sizeof (BoxesOvirtBrokerPrivate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	BOXES_BROKER_CLASS (klass)->add_source = boxes_ovirt_broker_real_add_source;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	BOXES_BROKER_CLASS (klass)->add_source_finish = boxes_ovirt_broker_real_add_source_finish;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_ovirt_broker_finalize;
#line 1345 "ovirt-broker.c"
}


static void boxes_ovirt_broker_instance_init (BoxesOvirtBroker * self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	self->priv = BOXES_OVIRT_BROKER_GET_PRIVATE (self);
#line 1352 "ovirt-broker.c"
}


static void boxes_ovirt_broker_finalize (GObject* obj) {
	BoxesOvirtBroker * self;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_OVIRT_BROKER, BoxesOvirtBroker);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	_g_hash_table_unref0 (self->priv->proxies);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/ovirt-broker.vala"
	G_OBJECT_CLASS (boxes_ovirt_broker_parent_class)->finalize (obj);
#line 1364 "ovirt-broker.c"
}


GType boxes_ovirt_broker_get_type (void) {
	static volatile gsize boxes_ovirt_broker_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_ovirt_broker_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesOvirtBrokerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_ovirt_broker_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesOvirtBroker), 0, (GInstanceInitFunc) boxes_ovirt_broker_instance_init, NULL };
		GType boxes_ovirt_broker_type_id;
		boxes_ovirt_broker_type_id = g_type_register_static (BOXES_TYPE_BROKER, "BoxesOvirtBroker", &g_define_type_info, 0);
		g_once_init_leave (&boxes_ovirt_broker_type_id__volatile, boxes_ovirt_broker_type_id);
	}
	return boxes_ovirt_broker_type_id__volatile;
}



